@@ -1,6 +1,6 @@
 package Lido::XML;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Moo;
 use Lido::XML::LIDO_1_0;
@@ -71,6 +71,16 @@ __END__
 
 Lido::XML - A Lido XML parser and writer
 
+=begin markdown
+
+# Status
+
+[![Build Status](https://travis-ci.org/LibreCat/Lido-XML.png)](https://travis-ci.org/LibreCat/Lido-XML)
+[![Coverage Status](https://coveralls.io/repos/LibreCat/Lido-XML/badge.png)](https://coveralls.io/r/LibreCat/Lido-XML)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/Lido-XML.png)](http://cpants.cpanauthors.org/dist/Lido-XML)
+
+=end markdown
+
 =head1 SYNOPSIS
 
     use Lido::XML
